div.star {
	left: auto;
	right: 0;
	letter-spacing: 0;
}
.star img, div.star a, div.star a:hover, div.star a:visited {
	right: auto;
	left: 0;
}
#plugin-information ul#sidemenu {
	left: auto;
	right: 0;
}
#plugin-information h2 {
	margin-right: 0;
	margin-left: 200px;
}
#plugin-information .fyi {
	margin-left: 5px;
	margin-right: 20px;
}
#plugin-information .fyi h2 {
	margin-left: 0;
}
#plugin-information .fyi ul {
	padding: 10px 7px 10px 5px;
}
#plugin-information #section-screenshots li p {
	padding-left: 0;
	padding-right: 20px;
}
#plugin-information .updated,
#plugin-information pre {
	margin-right: 0;
	margin-left: 215px;
}
#plugin-information .updated, #plugin-information .error {
	clear: none;
	direction: rtl;
}
#section-description {
	direction: ltr;
}
