.bar {
	border-right-color: transparent;
	border-left-color: #99d;
}

.plugins .togl {
	border-right-color: transparent;
	border-left-color: #ccc;
}

.post-com-count {
	background-image: url(../images/bubble_bg-rtl.gif);
}
.tablenav .tablenav-pages a {
	background: #eee url('../images/menu-bits-rtl.gif') repeat-x scroll right -379px;
}
#upload-menu li.current {
	border-right-color: transparent;
	border-left-color: #448abd;
}

#adminmenu .wp-submenu .current a.current {
	background: transparent url(../images/menu-bits-rtl.gif) no-repeat scroll  right -289px;
}

#adminmenu li.wp-menu-separator {
	background: transparent url(../images/menu-arrows.gif) no-repeat scroll right -34px;
}

.folded #adminmenu li.wp-menu-separator {
	background: transparent url(../images/menu-arrows.gif) no-repeat scroll left 5px;
}

#adminmenu li.wp-has-current-submenu .wp-menu-toggle,
#adminmenu li.wp-has-current-submenu:hover .wp-menu-toggle {
	background: transparent url(../images/menu-bits-rtl.gif) repeat-x scroll right -207px;
}

#adminmenu .wp-has-current-submenu ul li a.current {
	background: url(../images/menu-dark-rtl.gif) top right no-repeat !important;
}

#adminmenu li.wp-has-current-submenu a.wp-has-current-submenu,
#adminmenu .menu-top .current {
	background: url(../images/menu-bits-rtl.gif) top right repeat-x;
}

#adminmenu li.wp-has-current-submenu ul li a {
	background: url(../images/menu-dark-rtl.gif) bottom right no-repeat !important;
}

#adminmenu li.wp-has-current-submenu.wp-menu-open .wp-menu-toggle, #adminmenu li.wp-has-current-submenu:hover .wp-menu-toggle {
	background: transparent url(../images/menu-bits-rtl.gif) no-repeat right -207px;
}

#adminmenu .wp-has-submenu:hover .wp-menu-toggle,
#adminmenu .wp-menu-open .wp-menu-toggle {
	background: transparent url(../images/menu-bits-rtl.gif) repeat-x scroll right -109px;
}

#adminmenu a.wp-has-submenu {
	background: #f1f1f1 url(../images/menu-bits-rtl.gif) repeat-x scroll right -379px;
}

#adminmenu .wp-submenu a {
	background: #FFFFFF url(../images/menu-bits-rtl.gif) no-repeat scroll right -310px;
}

#adminmenu li.current a,
#adminmenu .wp-submenu a:hover {
	background: transparent url(../images/menu-bits-rtl.gif) no-repeat scroll  right -289px;
}

#adminmenu li.wp-has-current-submenu a.wp-has-submenu {
	background: #b5b5b5 url(../images/menu-bits-rtl.gif) repeat-x scroll right top;
}

.meta-box-sortables .postbox:hover .handlediv {
	background: transparent url(../images/menu-bits-rtl.gif) no-repeat scroll right -111px;
}
#favorite-toggle {
	background: transparent url(../images/fav-arrow-rtl.gif) no-repeat right -4px;
}
