/* This file contains the CSS data for the editable area(iframe) of TinyMCE */
html {
	background-color: #fff;
}

.aligncenter,
dl.aligncenter {
	display: block;
	margin-left: auto;
	margin-right: auto;
}

.alignleft {
	float: left;
}

.alignright {
	float: right;
}

.wp-caption {
	border: 1px solid #ddd;
	text-align: center;
	background-color: #f3f3f3;
	padding-top: 4px;
	margin: 10px;
	-moz-border-radius: 3px;
	-khtml-border-radius: 3px;
	-webkit-border-radius: 3px;
	border-radius: 3px;
}

.wp-caption img {
	margin: 0;
	padding: 0;
	border: 0 none;
}

.wp-caption-dd {
	font-size: 11px;
	line-height: 17px;
	padding: 0 4px 5px;
	margin: 0;
}

img.wpGallery {
	border: 1px dotted #cc0000;
	background: #ffffcc url("plugins/wpgallery/img/gallery.png") no-repeat scroll center center;
	width: 99%;
	height: 250px;
}

body.mceContentBody {
	font: 13px/19px Georgia, "Times New Roman", "Bitstream Charter", Times, serif;
	padding: 0.6em;
	margin: 0;
}

body.mceForceColors {
	background:#fff;
	color:#000;
}

h1 {font-size: 2em}
h2 {font-size: 1.5em}
h3 {font-size: 1.17em}
h4 {font-size: 1em}
h5 {font-size: .83em}
h6 {font-size: .75em}

.mceItemTable, .mceItemTable td, .mceItemTable th, .mceItemTable caption, .mceItemVisualAid {
	border: 1px dashed #BBB;
}

img {
	border:0;
}

td {
	font-size: 10px;
}

pre {
	font: 12px/18px "Courier New", monospace;
}

.mceIEcenter {
	text-align: center;
}
