body {
	font-family: Tahoma, arial;
}
h1 {
	font-family: arial;
	margin: 5px -4px 0 0;
}
ul, ol { padding: 5px 22px 5px 5px; }
.step, th { text-align: right; }
.submit input, .button, .button-secondary {
	font-family: Tahoma, arial;
	margin-right:0;
}
.form-table th {
	text-align: right;
}
