* html #wpcontent #adminmenu .wp-has-submenu .wp-menu-toggle {
	background: url(../images/menu-bits-rtl.gif) no-repeat scroll right -109px;
}

* html #wpcontent #adminmenu li.wp-has-current-submenu .wp-menu-toggle {
	background: url(../images/menu-bits-rtl.gif) no-repeat scroll right -206px;
}
* html #adminmenu {
	margin-left:0;
	margin-right: -80px;
}
* html div.folded #adminmenu {
	margin-left: 0;
	margin-right: -22px;
}
#wpcontent #adminmenu .wp-submenu li.wp-submenu-head {
	padding: 3px 10px 4px 4px;
}
.inline-edit-row fieldset label span.title {
	float: right;
}
.inline-edit-row fieldset label span.input-text-wrap {
	margin-right: 0;
}
p.search-box {
	float: left;
}
* html #poststuff h2 {
	margin-right: 0;
}
#bh {
	margin: 7px 10px 0 0;
	float: left;
}
#user_info + div#favorite-actions {
	right: auto;
	left: 15px;
}
#wphead-info {
	float: left;
}
/* without this dashboard widgets appear in one column for some screen widths */
div#dashboard-widgets {
	padding-right: 0;
	padding-left: 1px;
}
#tagchecklist span a {
	margin: 4px -9px 0 0;
}
.widefat th input {
	margin: 0 5px 0 0;
}
/* ---------- add by navid */
#TB_window {
	width: 670px;
	position: absolute;
	top: 50%;
	left: 50%;
	margin-right: 335px !important;
}
#dashboard_plugins {
	direction: ltr;
}
#dashboard_plugins h3.hndle {
	direction: rtl;
}
#dashboard_incoming_links ul li,
#dashboard_secondary ul li,
#dashboard_primary ul li,
p.row-actions {
	width: 100%;
}
#favorite-inside {
	position: absolute;
	right:0;
}
#post-status-info {
	height: 25px;
}
#screen-meta {
	position: static;
}
p.submit { /* quick edit and reply in edit-comments.php */
	height:22px;
}
.inner-sidebar { /* fix edit single comment */
	position: static;
}
form#widgets-filter { /* fix widget page */
	position: static;
}
